@@ -29,10 +29,7 @@
 
 import os
 import traceback
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch
+from unittest.mock import patch
 
 
 def get_test_dir():
