@@ -29,10 +29,7 @@
 
 import os
 import traceback
-try:
-    from unittest.mock import Mock, patch
-except ImportError:
-    from mock import Mock, patch
+from unittest.mock import Mock, patch
 
 import rospkg.os_detect
 
